@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.000001';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.001000';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -120,8 +120,20 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.000001';
 #pod 	[Pod2Html]
 #pod 	dir = doc
 #pod
+#pod 	#
 #pod 	# Release
+#pod 	#
 #pod 	[TestRelease]
+#pod
+#pod 	[Git::Check]
+#pod 	[Git::Commit]
+#pod 	commit_msg = Release %v%n%n%c
+#pod 	[Git::Tag]
+#pod 	tag_format  = %v
+#pod 	;# make a lightweight tag
+#pod 	tag_message =
+#pod 	[Git::Push]
+#pod
 #pod 	[ConfirmRelease]
 #pod
 #pod =cut
@@ -301,6 +313,17 @@ sub configure {
 		# Release
 		#
 		'TestRelease',                    # test before releasing
+
+		'Git::Check',                     # check for dirty files etc.
+		['Git::Commit' => {
+			'commit_msg' => 'Release %v%n%n%c',
+		}],
+		['Git::Tag' => {
+			'tag_format' => '%v',
+			'tag_message' => '',          # make a lightweight tag
+		}],
+		'Git::Push',
+
 		'ConfirmRelease',                 # ask for confirmation before releasing
     );
 }
@@ -311,7 +334,7 @@ __PACKAGE__->meta->make_immutable;
 {
 	package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
 	# ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '2.000001';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '2.001000';
 use Moose;
 	use namespace::autoclean;
 
@@ -359,7 +382,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 2.000001
+version 2.001000
 
 =head1 SYNOPSIS
 
@@ -483,8 +506,20 @@ Currently this plugin bundle is equivalent to:
 	[Pod2Html]
 	dir = doc
 
+	#
 	# Release
+	#
 	[TestRelease]
+
+	[Git::Check]
+	[Git::Commit]
+	commit_msg = Release %v%n%n%c
+	[Git::Tag]
+	tag_format  = %v
+	;# make a lightweight tag
+	tag_message =
+	[Git::Push]
+
 	[ConfirmRelease]
 
 =head1 METHODS
